from sympy import symbols, Eq, solve, simplify
from sympy.parsing.sympy_parser import parse_expr

def solve_equation(equation_str, var='x'):
    """
    Solves a single-variable algebraic equation.

    Args:
        equation_str (str): The equation string, e.g. "x**2 - 4 = 0"
        var (str): The variable to solve for

    Returns:
        List of solutions
    """
    x = symbols(var)
    if '=' in equation_str:
        lhs, rhs = equation_str.split('=')
        lhs = parse_expr(lhs.strip())
        rhs = parse_expr(rhs.strip())
        eq = Eq(lhs, rhs)
    else:
        eq = Eq(parse_expr(equation_str), 0)

    return solve(eq, x)

def simplify_expression(expr_str):
    """
    Simplifies a symbolic expression.

    Args:
        expr_str (str): Expression string to simplify

    Returns:
        Simplified expression
    """
    return simplify(parse_expr(expr_str))
