from sympy import symbols, Eq
from sympy.parsing.sympy_parser import parse_expr
from sympy.plotting import plot_implicit


def plot_equation(equation_str):
    """
    Plot an implicit equation in x and y with fixed aspect ratio.

    Example:
        plot_equation("2*x + 3*y = 6")
        plot_equation("x**2 + y**2 = 25")
    """
    x, y = symbols('x y')
    if '=' in equation_str:
        lhs, rhs = equation_str.split('=')
        lhs_expr = parse_expr(lhs.strip())
        rhs_expr = parse_expr(rhs.strip())
        equation = Eq(lhs_expr, rhs_expr)
    else:
        expr = parse_expr(equation_str.strip())
        equation = Eq(expr, 0)

    p = plot_implicit(equation, show=False)
    p.aspect_ratio = (1, 1)  # Fix aspect ratio to avoid stretched shapes
    p.title = f"Plot of {equation_str}"
    p.show()